@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.95_11'; # TRIAL VERSION
+our $VERSION = '0.97_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -283,6 +283,7 @@ sub function
   my $address = $name =~ /^-?[0-9]+$/ ? $name : $self->find_symbol($name);
   croak "unable to find $name" unless defined $address || $self->ignore_not_found;
   return unless defined $address;
+  $address = @args > 0 ? _cast1() : _cast0() if $address == 0;
   my $function = FFI::Platypus::Function::Function->new($self, $address, $self->{abi}, $fixed_arg_count, $ret, @args);
   $wrapper
     ? FFI::Platypus::Function::Wrapper->new($function, $wrapper)
@@ -366,14 +367,18 @@ sub attach_cast
 sub sizeof
 {
   my($self,$name) = @_;
-  $self->{tp}->parse($name)->sizeof;
+  ref $self
+    ? $self->{tp}->parse($name)->sizeof
+    : $self->new->sizeof($name);
 }
 
 
 sub alignof
 {
   my($self, $name) = @_;
-  $self->{tp}->parse($name)->alignof;
+  ref $self
+    ? $self->{tp}->parse($name)->alignof
+    : $self->new->alignof($name);
 }
 
 
@@ -503,7 +508,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.95_11
+version 0.97_01
 
 =head1 SYNOPSIS
 
@@ -985,6 +990,7 @@ faster and may be useful if you are calling a particular cast a lot.
 =head2 sizeof
 
  my $size = $ffi->sizeof($type);
+ my $size = FFI::Platypus->sizeof($type);
 
 Returns the total size of the given type in bytes.  For example to get
 the size of an integer:
